@@ -37,8 +37,8 @@ import org.eclipse.debug.internal.ui.viewers.provisional.IAsynchronousContentAda
 import org.eclipse.debug.internal.ui.viewers.provisional.IAsynchronousLabelAdapter;
 import org.eclipse.debug.internal.ui.viewers.provisional.IChildrenRequestMonitor;
 import org.eclipse.debug.internal.ui.viewers.provisional.ILabelRequestMonitor;
+import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.jface.viewers.ViewerFilter;
-import org.eclipse.jface.viewers.ViewerSorter;
 
 /**
  * Model for an asynchronous viewer
@@ -68,25 +68,16 @@ public abstract class AsynchronousModel {
 
 	class EmptyContentAdapter extends AsynchronousContentAdapter {
 
-		/* (non-Javadoc)
-		 * @see org.eclipse.debug.internal.ui.viewers.provisional.AsynchronousContentAdapter#getChildren(java.lang.Object, org.eclipse.debug.internal.ui.viewers.provisional.IPresentationContext)
-		 */
 		@Override
 		protected Object[] getChildren(Object parent, IPresentationContext context) throws CoreException {
 			return EMPTY;
 		}
 
-		/* (non-Javadoc)
-		 * @see org.eclipse.debug.internal.ui.viewers.provisional.AsynchronousContentAdapter#hasChildren(java.lang.Object, org.eclipse.debug.internal.ui.viewers.provisional.IPresentationContext)
-		 */
 		@Override
 		protected boolean hasChildren(Object element, IPresentationContext context) throws CoreException {
 			return false;
 		}
 
-		/* (non-Javadoc)
-		 * @see org.eclipse.debug.internal.ui.viewers.provisional.AsynchronousContentAdapter#supportsPartId(java.lang.String)
-		 */
 		@Override
 		protected boolean supportsPartId(String id) {
 			return true;
@@ -549,9 +540,9 @@ public abstract class AsynchronousModel {
 	protected void setChildren(final ModelNode parentNode, List<Object> kids) {
         final Object[] children = filter(parentNode.getElement(), kids.toArray());
         final AsynchronousViewer viewer = getViewer();
-        ViewerSorter sorter = viewer.getSorter();
-        if (sorter != null) {
-        	sorter.sort(viewer, children);
+		ViewerComparator comparator = viewer.getComparator();
+        if (comparator != null) {
+        	comparator.sort(viewer, children);
         }
 
         ModelNode[] prevKids = null;
